@@ -4,9 +4,9 @@
  * Gnome Crystal
  * application.cc 
  *
- * Copyright (C) 2001-2002
+ * Copyright (C) 2001-2004
  *
- * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,12 +25,14 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
-#include <libgnomeprint/gnome-print-master.h>
-#include <libgnomeprint/gnome-print-dialog.h>
-#include <libgnomeprint/gnome-print-preview.h>
-#include <libgnomeprint/gnome-print-master-preview.h>
+#include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-print-job.h>
+#include <libgnomeprintui/gnome-print-dialog.h>
+#include <libgnomeprintui/gnome-print-job-preview.h>
 #include "application.h"
 #include "globals.h"
 #include "filesel.h"
@@ -52,13 +54,6 @@ static void on_file_open(GtkWidget *widget, gcApplication *app)
 	app->OnFileOpen();
 }
 
-static void on_file_open_new_win(GtkWidget *widget, gcApplication *app)
-{
-	gcApplication* pApp = new gcApplication();
-	Apps.push_back(pApp);
-	pApp->OnFileOpen();
-}
-
 static void on_file_save(GtkWidget *widget, gcApplication *app)
 {
 	app->OnFileSave();
@@ -108,29 +103,25 @@ static void on_view_close(GtkWidget *widget, gcApplication *app)
 	app->OnViewClose();
 }
 
-static void on_about()
+void on_about()
 {
-	char * authors[2]={"Jean Brfort",NULL};
-	GtkWidget* about = gnome_about_new(_("Gnome Crystal"), VERSION, _("(C) 1999-2002 by Jean Brfort"), (const gchar**) authors, NULL, PREFIX"/share/pixpmaps/gnome-crystal.png");
+	char * authors[]={"Jean Bréfort",NULL};
+	char * documentors[] = {NULL};
+	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gnome-crystal-logo.png", NULL);
+	char *translator_credits = _("translator_credits");
+	GtkWidget* about = gnome_about_new(_("Gnome Crystal"), VERSION,
+										_("(C) 1999-2004 by Jean Bréfort"),
+										_("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
+										(const gchar**) authors, (const gchar**) documentors,
+										(strcmp (translator_credits, "translator_credits") != 0 ? 
+											(const char *)translator_credits : NULL),
+										pixbuf);
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
+	SET_ICON(about);
 	gtk_widget_show_all(about);
 }
 
-static void on_help()
-{
-	gchar* helpfile = gnome_help_file_find_file("gcrystal", "index.html");
-	if (helpfile != NULL)
-	{
-		gchar* url = g_strconcat("ghelp:", helpfile, NULL);
-		gnome_help_goto(NULL, url);
-		g_free(url);
-		g_free(helpfile);
-	}
-	else
-	{
-		gnome_error_dialog(_("Couldn't find the Gnome Crystal manual"));
-	}
-}
-
 static void on_lattice(GtkWidget *widget, gcApplication *app)
 {
 	if (app) app->OnCrystalDefine(0);
@@ -141,7 +132,7 @@ static void on_atoms(GtkWidget *widget, gcApplication *app)
 	if (app) app->OnCrystalDefine(1);
 }
 
-static void on_bonds(GtkWidget *widget, gcApplication *app)
+static void on_lines(GtkWidget *widget, gcApplication *app)
 {
 	if (app) app->OnCrystalDefine(2);
 }
@@ -181,15 +172,10 @@ static bool on_quit(GtkWidget *widget, gcApplication *app)
 
 static void on_select(GtkWidget* widget, gcApplication *app)
 {
-	GtkWidget* w = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(widget), "page"));
+	GtkWidget* w = GTK_WIDGET(g_object_get_data(G_OBJECT(widget), "page"));
 	app->OnSelectView(w);
 }
 
-static void on_change_page(GtkWidget* widget, GtkNotebook* book, int page, gcApplication *app)
-{
-	app->OnChangePage(page);
-}
-
 static bool on_delete(GtkWidget* widget, GdkEventAny *event, gcApplication *app)
 {
 	while (app->OnViewClose()) while (gtk_events_pending()) gtk_main_iteration();
@@ -214,7 +200,7 @@ static void on_destroy(GtkWidget* widget, gcApplication *app)
 
 static void on_prefs(GtkWidget* widget, gcApplication *app)
 {
-	gcPrefsDlg* box = new gcPrefsDlg();
+	new gcPrefsDlg();
 }
 
 //Helper functions
@@ -230,11 +216,11 @@ static bool do_load(const gchar* filename, gcView* pView)
 		if (!pDoc->IsDirty()) return true;
 		else
 		{
-			gchar* str = g_strdup_printf(_("``%s'' has been modified since last saving. Do you wish to come back to saved version?"), pDoc->GetTitle());
-			GtkWidget* mbox = gnome_message_box_new(str, GNOME_MESSAGE_BOX_QUESTION, GNOME_STOCK_BUTTON_YES,
-												GNOME_STOCK_BUTTON_NO, NULL);
-			int res = gnome_dialog_run(GNOME_DIALOG(mbox));
-			if (res != GNOME_YES) return true;
+			gchar* str = g_strdup_printf(_("\"%s\" has been modified since last saving. Do you wish to come back to saved version?"), pDoc->GetTitle());
+			GtkWidget* mbox = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+			SET_ICON(mbox);
+			int res = gtk_dialog_run(GTK_DIALOG(mbox));
+			if (res != GTK_RESPONSE_YES) return true;
 		}
 	}
 	if (pDoc->Load(filename))
@@ -248,7 +234,7 @@ static bool do_load(const gchar* filename, gcView* pView)
 	return false;
 }
 
-static void do_save_as(const gchar* filename, gcView* pView)
+void do_save_as(const gchar* filename, gcView* pView)
 {
 	gcDocument *pDoc = pView->GetDocument();
 	pDoc->SetFileName(filename);
@@ -256,7 +242,7 @@ static void do_save_as(const gchar* filename, gcView* pView)
 }
 
 #ifdef HAVE_LIBJPEG
-static void do_export_jpeg(const gchar *filename, gcView* pView)
+void do_export_jpeg(const gchar *filename, gcView* pView)
 {
 	if (!pView) return;
 	pView->ExportJPG(filename);
@@ -264,14 +250,14 @@ static void do_export_jpeg(const gchar *filename, gcView* pView)
 #endif
 
 #ifdef HAVE_PNG
-static void do_export_png(const gchar *filename, gcView* pView)
+void do_export_png(const gchar *filename, gcView* pView)
 {
 	if (!pView) return;
 	pView->ExportPNG(filename);
 }
 #endif
 
-static void do_export_vrml(const gchar *filename, gcView* pView)
+void do_export_vrml(const gchar *filename, gcView* pView)
 {
 	gcDocument *pDoc = pView->GetDocument();
 	if (pDoc) pDoc->OnExportVRML(filename, pView);;
@@ -307,84 +293,104 @@ bool RequestApp(gcView* pView)
 
 //Implementation of gcApplication class
 
+static GnomeUIInfo export_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("VRML"), N_("Export to VRML"), on_export_vrml),
+#ifdef HAVE_PNG
+	GNOMEUIINFO_ITEM_NONE(N_("PNG"), N_("Export view to png file"), on_export_png),
+#endif
+#ifdef HAVE_LIBJPEG
+	GNOMEUIINFO_ITEM_NONE(N_("Jpeg"), N_("Export view to jpeg file"), on_export_jpeg),
+#endif
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo file_menu [] = {
+	GNOMEUIINFO_MENU_NEW_ITEM(N_("_New File"), N_("Create a new file"), on_file_new, NULL),
+	GNOMEUIINFO_MENU_OPEN_ITEM(on_file_open, NULL),
+	{ GNOME_APP_UI_ITEM, N_("O_pen in a new window..."),
+		N_("Open a file in a new window"), (gpointer)on_file_save_as, NULL, NULL, \
+		GNOME_APP_PIXMAP_NONE, NULL, 'o', (GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), NULL },
+	GNOMEUIINFO_MENU_SAVE_ITEM(on_file_save, NULL),
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(on_file_save_as, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_SUBTREE_HINT(N_("_Export"), N_("Export data or graphics"), export_menu),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_PRINT_ITEM(on_file_print, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_CLOSE_ITEM(on_file_close, NULL),
+	GNOMEUIINFO_MENU_EXIT_ITEM(on_quit, NULL),
+	GNOMEUIINFO_END
+};
+ 
+static GnomeUIInfo edit_menu [] = {
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM(on_prefs, NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo crystal_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("_Lattice..."), N_("Define the lattice"), on_lattice),
+	GNOMEUIINFO_ITEM_NONE(N_("_Atoms..."), N_("Define the lattice"), on_atoms),
+	GNOMEUIINFO_ITEM_NONE(N_("_Bonds and lines..."), N_("Add bonds and lines"), on_lines),
+	GNOMEUIINFO_ITEM_NONE(N_("_Size..."), N_("Define size"), on_size),
+	GNOMEUIINFO_ITEM_NONE(N_("_Cleavages..."), N_("Add cleavages to remove some planes"), on_cleavages),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo view_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("View _settings..."), N_("Choose background color and model position"), on_view_settings),
+	GNOMEUIINFO_END
+};
+static GnomeUIInfo windows_menu [] = {
+	GNOMEUIINFO_MENU_NEW_WINDOW_ITEM(on_view_new, NULL),
+	GNOMEUIINFO_MENU_CLOSE_WINDOW_ITEM(on_view_close, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_END
+};
+ 
+static GnomeUIInfo help_menu [] = {
+	GNOMEUIINFO_HELP((void*)"gnome-crystal"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(on_about, NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo main_menu [] = {
+	GNOMEUIINFO_MENU_FILE_TREE(&file_menu),
+	GNOMEUIINFO_MENU_EDIT_TREE(&edit_menu),
+	GNOMEUIINFO_SUBTREE(N_("_Crystal"), &crystal_menu),
+	GNOMEUIINFO_MENU_VIEW_TREE(&view_menu),
+	GNOMEUIINFO_MENU_WINDOWS_TREE(&windows_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(&help_menu),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo tool_bar [] = {
+	GNOMEUIINFO_ITEM_STOCK(N_("New"), N_("Create a new file"), on_file_new, GTK_STOCK_NEW),
+	GNOMEUIINFO_ITEM_STOCK(N_("Open"), N_("Open a file"), on_file_open, GTK_STOCK_OPEN),
+	GNOMEUIINFO_ITEM_STOCK(N_("Save"), N_("Save active file"), on_file_save, GTK_STOCK_SAVE),
+	GNOMEUIINFO_ITEM_STOCK(N_("Print"), N_("Print active view"), on_file_print, GTK_STOCK_PRINT),
+	GNOMEUIINFO_ITEM_STOCK(N_("Close"), N_("Close active file"), on_file_close, GTK_STOCK_CLOSE),
+	GNOMEUIINFO_ITEM_STOCK(N_("Quit"), N_("Quit Gnome Crystal"), on_quit, GTK_STOCK_QUIT),
+	GNOMEUIINFO_END
+};
+
 gcApplication::gcApplication()
 {
-	GladeXML *xml ;
-	xml = glade_xml_new(PREFIX"/share/gcrystal/glade/application.glade", "app");
-
-	m_App = glade_xml_get_widget(xml, "app");
-	gtk_signal_connect(GTK_OBJECT(m_App), "delete_event", (GtkSignalFunc)on_delete, this);
-	gtk_signal_connect(GTK_OBJECT(m_App), "destroy", (GtkSignalFunc)on_destroy, this);
-	m_Notebook = GTK_NOTEBOOK(glade_xml_get_widget(xml, "notebook"));
-	gtk_signal_connect(GTK_OBJECT(m_Notebook), "switch_page", (GtkSignalFunc)on_change_page, this); 
-
-	m_WindowsMenu = (GtkMenu*) ((glade_xml_get_widget(xml, "Placeholder"))->parent);	//Connect callbacks to menu items
-	GtkObject *obj;
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "exit"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_quit, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "quit_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_quit, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "new"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_new, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "new_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_new, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "open"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_open, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "open_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_open, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "open_new_win"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_open_new_win, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "save"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_save, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "save_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_save, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "save_as"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_save_as, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "close"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_close, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "close_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_close, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "print"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_file_print, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "vrml"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_export_vrml, this);
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "jpeg"));
-#ifdef HAVE_LIBJPEG
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_export_jpeg, this); 
-#else
-	gtk_widget_hide(GTK_WIDGET(obj));
-#endif
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "png"));
-#ifdef HAVE_PNG
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_export_png, this); 
-#else
-	gtk_widget_hide(GTK_WIDGET(obj));
-#endif
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "print_btn"));
-	gtk_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_print, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "lattice"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_lattice, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "atoms"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_atoms, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "bonds"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_bonds, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "size"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_size, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "cleavages"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_cleavages, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "view_settings"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_view_settings, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "preferences"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_prefs, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "new_view"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_view_new, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "close_view"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_view_close, this); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "about"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_about, NULL); 
-	obj = GTK_OBJECT(glade_xml_get_widget(xml, "manual"));
-	gtk_signal_connect(obj, "activate", (GtkSignalFunc)on_help, NULL); 
+	m_App = gnome_app_new(_("Gnome Crystal"), _("Gnome Crystal"));
+	SET_ICON(m_App);
+	gnome_app_create_menus_with_data((GnomeApp*)m_App, main_menu, this);
+	gnome_app_create_toolbar_with_data((GnomeApp*)m_App, tool_bar, this);
+	m_WindowsMenu = GTK_MENU(windows_menu[0].widget->parent);
+	GtkWidget *bar = gnome_appbar_new(true, true, GNOME_PREFERENCES_ALWAYS);
+	gnome_appbar_set_default(GNOME_APPBAR(bar), _("Ready."));
+	gnome_app_set_statusbar((GnomeApp*)m_App, bar);
+	gnome_app_install_appbar_menu_hints(GNOME_APPBAR(bar), main_menu);
+	g_signal_connect(G_OBJECT(m_App), "delete_event", (GtkSignalFunc)on_delete, this);
+	g_signal_connect(G_OBJECT(m_App), "destroy", G_CALLBACK(on_destroy), NULL);
+	m_Notebook = GTK_NOTEBOOK(gtk_notebook_new());
+	gtk_widget_set_size_request(GTK_WIDGET(m_Notebook), 300, 300);
+	gnome_app_set_contents((GnomeApp*)m_App, GTK_WIDGET(m_Notebook));
 	UpdateConfig();
+	gtk_widget_show_all(m_App);
 }
 
 gcApplication::~gcApplication()
@@ -397,7 +403,7 @@ void gcApplication::OnFileNew()
 	gchar tmp[32];
 	g_snprintf(tmp, sizeof(tmp), _("Untitled%d"), nNewDocs++);
 	pDoc->SetTitle(tmp);
-	gcView* pView = pDoc->GetView();
+	gcView* pView = (gcView*)pDoc->GetView();
 	AddView(pView);
 	m_bFileOpening = false;
 }
@@ -405,14 +411,13 @@ void gcApplication::OnFileNew()
 void gcApplication::OnFileOpen()
 {
 	gcView* pView;
-	gcDocument* pDoc;
 	if (m_Views.empty())
 	{
 		OnFileNew();
 		m_bFileOpening = true;
 	}
 	pView = m_Views.back();
-	gcFileSel* FileSel = new gcFileSel(_("Load a model..."), (void (*)(const    gchar*, gcView*))do_load, false, ".gcrystal", pView);
+	new gcFileSel(_("Load a model..."), (void (*)(const    gchar*, gcView*))do_load, false, ".gcrystal", pView);
 }
 
 void gcApplication::OnFileSave()
@@ -429,7 +434,7 @@ void gcApplication::OnFileSaveAs()
 	if (!m_pActiveView) return;
 	gcDocument* pDoc = m_pActiveView->GetDocument();
 	if (!pDoc) return;
-	gcFileSel* FileSel = new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", m_pActiveView);
+	new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", m_pActiveView);
 }
 
 bool gcApplication::OnFileClose()
@@ -449,7 +454,6 @@ bool gcApplication::OnFileClose()
 	if (!pDoc->VerifySaved()) return false;
 	std::list<gcApplication*>::iterator i;
 	std::list<gcView*>::iterator j;
-	gcView *pView;
 	bool bEnded;
 	do
 	{
@@ -477,7 +481,7 @@ void gcApplication::OnSelectView(GtkWidget* widget)
 	gint i;
 	i = gtk_notebook_page_num(m_Notebook, widget);
 	if(i != gtk_notebook_get_current_page(m_Notebook))
-		gtk_notebook_set_page(m_Notebook, i);
+		gtk_notebook_set_current_page(m_Notebook, i);
 }
 
 void gcApplication::OnCrystalDefine(int page)
@@ -489,65 +493,59 @@ void gcApplication::OnCrystalDefine(int page)
 void gcApplication::OnViewSettings()
 {
 	if (!m_pActiveView) return;
-	gcViewSettingsDlg* pDlg = new gcViewSettingsDlg(m_pActiveView);
+	new gcViewSettingsDlg(m_pActiveView);
 }
 
 void gcApplication::OnFilePrint()
 {
-	GnomePrinter *printer = NULL;
+	GnomePrintConfig* config = gnome_print_config_default();
 	GnomePrintContext *pc;
-	GnomePrintMaster *gpm = NULL;
-	int do_preview, copies = 1, collate = 0;
+	GnomePrintJob *gpj = gnome_print_job_new(config);
+	int do_preview = 0, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
-	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new("Print test", GNOME_PRINT_DIALOG_COPIES));
+	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)"Print test", GNOME_PRINT_DIALOG_COPIES));
+	SET_ICON (gpd);
 	gnome_print_dialog_set_copies(gpd, copies, collate);
-	switch (gnome_dialog_run(GNOME_DIALOG(gpd)))
+	switch (gtk_dialog_run(GTK_DIALOG(gpd)))
 	{
-	case GNOME_PRINT_PRINT:
+	case GNOME_PRINT_DIALOG_RESPONSE_PRINT:
 		do_preview = 0;
 		break;
-	case GNOME_PRINT_PREVIEW:
+	case GNOME_PRINT_DIALOG_RESPONSE_PREVIEW:
 		do_preview = 1;
 		break;
-	case GNOME_PRINT_CANCEL:
-		gnome_dialog_close (GNOME_DIALOG(gpd));
+	case GNOME_PRINT_DIALOG_RESPONSE_CANCEL:
+		gtk_widget_destroy (GTK_WIDGET(gpd));
 		return;
 	}
-
-	gpm = gnome_print_master_new();
-	gnome_print_dialog_get_copies(gpd, &copies, &collate);
-	gnome_print_master_set_copies(gpm, copies, collate);
-	gnome_print_master_set_printer(gpm, gnome_print_dialog_get_printer(gpd));
-	gnome_dialog_close (GNOME_DIALOG(gpd));
-
-	pc = gnome_print_master_get_context(gpm);
-	gnome_print_beginpage(pc, "");
-	const GnomePaper* Paper = gnome_print_master_get_paper(gpm);
+	gtk_widget_destroy(GTK_WIDGET(gpd));
+	pc = gnome_print_job_get_context (gpj);
+	gnome_print_beginpage(pc, (const guchar*)"");
 	gdouble width, height;
-	width = gnome_paper_pswidth(Paper);
-	height = gnome_paper_psheight(Paper);
+	gnome_print_job_get_page_size_from_config(config, &width, &height);
 	m_pActiveView->Print(pc, width, height);
 	gnome_print_showpage(pc);
-	gnome_print_master_close(gpm);
+	g_object_unref(pc);
+	gnome_print_job_close(gpj);
 	if (do_preview)
 	{
-		GnomePrintMasterPreview *pmp;
-		pmp = gnome_print_master_preview_new(gpm, _("Preview"));
-		gtk_widget_show(GTK_WIDGET(pmp));
+		GtkWidget *preview = gnome_print_job_preview_new (gpj, (const guchar*)_("Preview"));
+		SET_ICON (preview);
+		gtk_widget_show (preview);
 	}
 	else
 	{
-		gnome_print_master_print(gpm);
+		gnome_print_job_print(gpj);
 	}
-
-	gnome_print_context_close (pc);
+	g_object_unref (gpj);
+	gnome_print_config_unref(config);
 }
 
 #ifdef HAVE_LIBJPEG
 void gcApplication::OnExportJPEG()
 {
 	if (!m_pActiveView) return;
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a Jpeg file..."), do_export_jpeg, true, ".jpg", m_pActiveView);
+	new gcFileSel(_("Export model as a Jpeg file..."), do_export_jpeg, true, ".jpg", m_pActiveView);
 }
 #endif
 
@@ -555,14 +553,14 @@ void gcApplication::OnExportJPEG()
 void gcApplication::OnExportPNG()
 {
 	if (!m_pActiveView) return;
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a PNG file..."), do_export_png, true, ".png", m_pActiveView);
+	new gcFileSel(_("Export model as a PNG file..."), do_export_png, true, ".png", m_pActiveView);
 }
 #endif
 
 void gcApplication::OnExportVRML()
 {
 	if (!m_pActiveView) return;
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a VRML file..."), do_export_vrml, true, ".wrl", m_pActiveView);
+	new gcFileSel(_("Export model as a VRML file..."), do_export_vrml, true, ".wrl", m_pActiveView);
 }
 
 void gcApplication::OnViewNew()
@@ -610,7 +608,7 @@ bool gcApplication::OnViewClose(gcView* pView)
 	{
 		w = gtk_notebook_get_nth_page(m_Notebook, i);
 		if (w == NULL) return false; //should not occur
-		if (pView == ((gcView*) gtk_object_get_data(GTK_OBJECT(w), "view"))) break;
+		if (pView == ((gcView*) g_object_get_data(G_OBJECT(w), "view"))) break;
 		else i++;
 	}
 	while (w);
@@ -622,7 +620,7 @@ bool gcApplication::OnViewClose(gcView* pView)
 	{
 		i = gtk_notebook_get_current_page(m_Notebook);
 		w = gtk_notebook_get_nth_page(m_Notebook, i);
-		m_pActiveView = (w) ? (gcView*) gtk_object_get_data(GTK_OBJECT(w), "view") : NULL;
+		m_pActiveView = (w) ? (gcView*) g_object_get_data(G_OBJECT(w), "view") : NULL;
 	}
 	if (m_Views.empty() && (Apps.size() > 1))
 	{
@@ -652,14 +650,14 @@ void gcApplication::AddView(gcView* pView)
 	pView->SetLabel(GTK_LABEL(label));
 	GtkWidget* item = gtk_menu_item_new_with_label(tmp);
 	pView->SetMenu(GTK_MENU_ITEM(item));
-	gtk_object_set_data(GTK_OBJECT(item), "page", widget);
-	gtk_object_set_data(GTK_OBJECT(widget), "menu", item);
-	gtk_object_set_data(GTK_OBJECT(widget), "view", pView);
+	g_object_set_data(G_OBJECT(item), "page", widget);
+	g_object_set_data(G_OBJECT(widget), "menu", item);
+	g_object_set_data(G_OBJECT(widget), "view", pView);
 	gtk_widget_show(item);
-	gtk_menu_append(m_WindowsMenu, item);
+	gtk_menu_shell_append((GtkMenuShell*)m_WindowsMenu, item);
 	gtk_notebook_append_page(m_Notebook, widget, label);
-	gtk_notebook_set_page(m_Notebook, g_list_length(m_Notebook->children) - 1);
-	gtk_signal_connect(GTK_OBJECT(item), "activate", (GtkSignalFunc)on_select, this); 
+	gtk_notebook_set_current_page(m_Notebook, g_list_length(m_Notebook->children) - 1);
+	g_signal_connect(G_OBJECT(item), "activate", (GtkSignalFunc)on_select, this); 
 }
 
 bool gcApplication::LoadFile(char* filename)
@@ -746,15 +744,15 @@ void gcApplication::SelectView(gcView* pView)
 	{
 		w = gtk_notebook_get_nth_page(m_Notebook, i);
 		if (w == NULL) return; //should not occur
-		if (pView == ((gcView*) gtk_object_get_data(GTK_OBJECT(w), "view"))) break;
+		if (pView == ((gcView*) g_object_get_data(G_OBJECT(w), "view"))) break;
 		else i++;
 	}
 	while (w);
-	gtk_notebook_set_page(m_Notebook, i);
+	gtk_notebook_set_current_page(m_Notebook, i);
 }
 
 void gcApplication::OnChangePage(int i)
 {
 	GtkWidget *w = gtk_notebook_get_nth_page(m_Notebook, i);
-	m_pActiveView = (gcView*)gtk_object_get_data(GTK_OBJECT(w), "view");
+	m_pActiveView = (gcView*)g_object_get_data(G_OBJECT(w), "view");
 }
