@@ -246,7 +246,7 @@ bool gcAtomsDlg::Apply()
 	
 	struct AtomStruct* s;
 	gcAtom* pAtom;
-	for (int i = 0; i  < m_Atoms->len; i++)
+	for (int i = 0; i  < (int) m_Atoms->len; i++)
 	{
 		s = &g_array_index(m_Atoms, struct AtomStruct, i);
 		pAtom = new gcAtom(s->Elt, s->x, s->y, s->z);
@@ -354,7 +354,7 @@ void gcAtomsDlg::AtomSelect(GtkTreeSelection *Selection)
 			gtk_entry_set_text(AtomR, buf);
 			gtk_option_menu_set_history(RadiusMenu, 0);
 		}
-		else for (int i = 1; i < m_RadiiIndex.size(); i++)
+		else for (int i = 1; i < (int) m_RadiiIndex.size(); i++)
 		{
 			int j = m_RadiiIndex[i];
 			if (r.type != m_Radii[j]->type) continue;
@@ -410,7 +410,7 @@ void gcAtomsDlg::OnEdited(GtkCellRendererText *cell, const gchar *path_string, c
 
 	gtk_tree_model_get_iter (GTK_TREE_MODEL(AtomList), &iter, path);
 
-	gint i = gtk_tree_path_get_indices (path)[0], j  = (long)g_object_get_data (G_OBJECT (cell), "column");
+	gint j  = (long)g_object_get_data (G_OBJECT (cell), "column");
 	double x = atof(new_text);
 	gtk_list_store_set(AtomList, &iter, j, x, -1);
 	switch (j)
