@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -322,7 +322,7 @@ bool gcLinesDlg::Apply()
 	//Add new lines from array
 	
 	struct LineStruct* s;
-	for (int i = 0; i  < m_Lines->len; i++)
+	for (int i = 0; i  < (int) m_Lines->len; i++)
 	{
 		s = &g_array_index(m_Lines, struct LineStruct, i);
 		Lines->push_back(new CrystalLine((s->duplicated)? normal: gcu::unique, s->x1, s->y1, s->z1, s->x2, s->y2, s->z2, s->r, (float)s->Red, (float)s->Green, (float)s->Blue, (float)s->Alpha));
@@ -420,7 +420,7 @@ void gcLinesDlg::OnEdited(GtkCellRendererText *cell, const gchar *path_string, c
 
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(LineList), &iter, path);
 
-	gint i = gtk_tree_path_get_indices (path)[0], j  = (int)g_object_get_data(G_OBJECT (cell), "column");
+	gint j  = (long)g_object_get_data(G_OBJECT (cell), "column");
 	double x = atof(new_text);
 	gtk_list_store_set(LineList, &iter, j, x, -1);
 	switch (j)
