@@ -93,11 +93,6 @@ extern "C" {
 
 }//end of extern "C" section
 
-static void on_destroyed(GtkWidget *widget, gcView *pView)
-{
-	pView->OnDestroyed(widget);
-}
-
 gcView::gcView(gcDocument *pDoc): CrystalView((CrystalDoc*)pDoc)
 {
 	m_fAngle = FoV;
@@ -208,7 +203,7 @@ bool gcView::LoadOld(xmlNodePtr node)
 			txt = (char*)xmlNodeGetContent(child);
 			if (txt)
 			{
-				int result = sscanf(txt, "%lg", &m_fAngle);
+				sscanf(txt, "%lg", &m_fAngle);
 				xmlFree(txt);
 			}
 		}
